// Solution to problem C. Competitive Programmaing, from CCSS 2015.
//
// Uses two priority queues:
// * a queue sortS containing problems whose solutions have yet to be
//   thought of. This queue is sorted on `release times' of the problems
//   (the moment when the solution is thought of),
// * a queue readyQ containing problems whose solutions have been thought of.
//   This queue is sorted on remaining implementation time.
//
// Solution by Rudy van Vliet, 27 April 2015

#include <iostream>
using namespace std;

const int maxProblems=15;

//*************************************************************************

// An item of a prioriry queue.
class Item
{ public:
    int number,
        prio;

    Item (int nwnumber, int nwprio)
    { number = nwnumber;
      prio = nwprio;
    }
};

//*************************************************************************

// A priority queue with at most maxProblems items,
// simply organised as an array sorted on prioriies (lowest values first).
// Uses InsertionSort to keep array sorted.
class PriorQ
{ public:
    PriorQ ()
    { first = 0;
      last = -1;
    }

    ~PriorQ ()
    { int i;

      for (i=first;i<=last;i++)
        delete (queue[i]);
    }
    
    void reset ()
    { int i;

      for (i=first;i<=last;i++)
        delete (queue[i]);

      first = 0;
      last = -1;
    }

    bool isEmpty ()
    {
      if (first > last)
        return true;
      else
        return false;
    }

    bool isFull ()
    {
      if (first==0 && last==maxProblems-1)
        return true;
      else
        return false;
    }

     // Insert an item with certain number and priority.
    void insert (int number, int prio)
    { Item* newItem;
      int i, j;

      if (isFull())
        cout << "Priority Queue is full, so we cannot inset another item.\n";
      else
      {
        newItem = new Item (number, prio);

        i = first;
        while (i<=last && (queue[i]->prio <= prio))
          i++;

         // New item must be inserted at position i.
         // We either move the earlier items forwards (in direction
         // of position 0 in the queue), or move later items backwards.

        if (first>0)  // move all items before i forward
        { for (j=first;j<i;j++)
            queue[j-1] = queue[j];
          first --;
          i --;
        }
        else
        { for (j=last;j>=i;j--)
            queue[j+1] = queue[j];
          last ++;
        }

        queue[i] = newItem;

      } // not full

    } // insert


    void deleteMin (int &number, int &prio)
    {
      if (isEmpty())
        cout << "Priority Queue is empty, so we cannot delete its minimum.\n";
      else
      { number = queue[first]->number;
        prio = queue[first]->prio;
        delete (queue[first]);
        first ++;
      }

    } // deleteMin


    int getMinPrio ()
    {
      if (isEmpty())
      { cout << "Priority Queue is empty, so we cannot get the minimal priority.\n";
        return 0;
      }
      else
        return queue[first]->prio;
    }
      
  private:
    int first, last;
    Item* queue[maxProblems];

};

//*************************************************************************

// Check if value is in the interval minim--maxim (inclusive).
void checkInterval (int value, int minim, int maxim)
{
  if (value<minim || value>maxim)
    cout << "The value " << value << " is not in the interval "
           << minim << "--" << maxim << ".\n";

}  // checkInterval

//*************************************************************************

int main ()
{ int T, Inst;
  int D,
      N, i,
      i0, j0,
      S[maxProblems+1],
      C[maxProblems+1],
      solved, penalty,
      start, currentTime, remaining;
  PriorQ sortedS,  // problems for which solution has yet to be thought of,
                   // sorted on S[i]
         readyQ;   // problems for which solution has been thought of,
                   // so which are ready to be implemented, sorted
                   // on remaining[i]

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  { cin >> D >> N;

    checkInterval (D, 60, 600);
    checkInterval (N, 1, maxProblems);

    for (i=1;i<=N;i++)
    { cin >> S[i] >> C[i];
      checkInterval (S[i], 0, D);
      checkInterval (C[i], 1, D);
      sortedS.insert (i, S[i]);
    }

    solved = 0;
    penalty = 0;
    start = 0;

      // Move all problems from sortedS to readyQ.
    while (!(sortedS.isEmpty()))
    { sortedS.deleteMin (i0, currentTime);
        // By assumption, currentTime (which is S[i0]) <= D.
        // Therefore, other jobs that have been completely implemented
        // at currentTime, have been implemented in time.

        // Have any problems been completely implemented,
        // since the previous time, we moved a problem from sortedS to readyQ?
      while (!(readyQ.isEmpty()) && (currentTime-start >= readyQ.getMinPrio()))
      { readyQ.deleteMin (j0, remaining);
        solved ++;
        penalty += (start+remaining);
        start = start+remaining;
      }

      if (!(readyQ.isEmpty()))
        // Currently (at currentTime), a problem is being implemented.
        // Update its remaining implementation time.
      { readyQ.deleteMin (j0, remaining);
        remaining -= (currentTime-start);
        readyQ.insert (j0, remaining);
      }

      readyQ.insert (i0, C[i0]);
      start = currentTime;

    }

      // Check how many problems from readyQ have been completely implemented
      // by the end of the contest.
    while (!(readyQ.isEmpty()) && (D-start >= readyQ.getMinPrio()))
    { readyQ.deleteMin (j0, remaining);
      solved ++;
      penalty += (start+remaining);
      start = start+remaining;
    }

    sortedS.reset();
    readyQ.reset();

    cout << solved << " " << penalty << endl;

  }

  return 0;
}
