// Solution to problem D. Dice, from CCSS 2015.
//
// Use brute force to count the number of allowed lines of dice.
// A line of dice is allowed, if it does not have a subline that can be split
// into two subsublines that have the same sum.
//
// We stop extending a line of dice, as soon as we discover a `wrong' subline.
// When we examine whether or not a given subline can be split into
// two subsublines with the same sum, we first calculate the total
// sum of the subline and then iteratively increase the sum of the left
// subsubline, while decreasing the sum of the right subsubline.
//
// Solution by Rudy van Vliet, 27 April 2015

#include <iostream>
using namespace std;
const int maxValue=9;  // the maximal value on a face of a die
const int maxK=6;      // the maximal number of different values on a die
const int maxN=10;     // the maximal number of dice
bool used[maxValue+1];
int number[maxK+1],
    face[maxN+1],   // face[j] = the (visible) face of die j
    numberOfLines;

//*************************************************************************

// Check if value is in the interval minim--maxim (inclusive).
void checkInterval (int value, int minim, int maxim)
{
  if (value<minim || value>maxim)
    cout << "The value " << value << " is not in the interval "
           << minim << "--" << maxim << ".\n";

}  // checkInterval

//*************************************************************************

// Check if the prefix face[1..j] is allowed.
// For this, we try to split the subline face[leftpos..j] in two,
// for all possible positions leftpos.
// Pre: 1 <= j <= n
//      face[1..j-1] is allowed.
bool allowed (int j)
{ bool OK;
  int totalsum,  // sum of face[leftpos..j]
      leftpos,   // left position of subline we try to split
      split,     // position where we split face[leftpos..j]
      leftsum,   // is face[leftpos..split]
      rightsum;  // is face[split+1..j]

  OK = true;
  totalsum = face[j];
  leftpos = j-1;
  while (OK && leftpos>0)
  { totalsum += face[leftpos];

    split = leftpos-1;
    leftsum = 0;
    rightsum = totalsum;
 
    while (OK && leftsum<rightsum)
     // Eventually, if split became j, then leftsum would become totalsum
     // and rightsum would become 0.
     // Hence, this loop is guaranteed to terminate.
    { split ++;
      leftsum += face[split];
      rightsum -= face[split];

      if (leftsum==rightsum)
        OK = false;
    }

    leftpos --;
  }

  return OK;

}  // allowed

//*************************************************************************

// Count the number of allowed lines with a given prefix face[1..j].
// Pre: 0 <= j < n
//      face[1..j] is allowed
void countLines (int j, int n, int k)
{ int i;

  j++;
  for (i=1;i<=k;i++)
    // try number[i] on position j
  { face[j] = number[i];
    if (allowed(j))
    { if (j==n)
        numberOfLines ++;
      else
        countLines (j, n, k);
    }
  }

}  // countLines

//*************************************************************************

int main ()
{ int T, Inst;
  int n, k,
      i, l,
      value;

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  {
    cin >> n;
    checkInterval (n, 1, maxN);

    for (i=1;i<=maxValue;i++)
      used[i] = false;

    for (l=1;l<=maxK;l++)
    { cin >> value;
      checkInterval (value, 1, maxValue);
      used[value] = true;
    }

    k = 0;
    for (i=1;i<=maxValue;i++)
    { if (used[i])
      { k++;
        number[k] = i;
      }
    }
    
    numberOfLines = 0;
    countLines (0, n, k);

    cout << numberOfLines << endl;

  }

  return 0;

}
