// Solution to problem E. European Energy Union, from CCSS 2015.
//
// Uses adjacency list representation of graph.
// Uses repeated breadth first search to find connected components.
//
// Solution by Rudy van Vliet, 29 April 2015

#include <iostream>
using namespace std;
const int maxC = 2000;
const int maxP = 1000000;
bool done[maxC+1];

class AdjLEntry
{ public:
    AdjLEntry (int nwNeighbour, AdjLEntry *nwNext)
    { neighbour = nwNeighbour;
      next = nwNext;
    }

    int neighbour;
    AdjLEntry *next;
};

AdjLEntry *neighbours[maxC+1];

//*************************************************************************

// Simple implementation of FifoQ containing integers (countries).
class FifoQ
{ public:
    FifoQ ()
    { first = 0;
      last = -1;
    }

    bool isEmpty()
    {
      if (last<first)
        return true;
      else
        return false;
    }

    bool isFull()
    {
      if (last==maxC-1)
        return true;
      else
        return false;
    }

    void add (int i)
    {
      if (isFull())
        cout << "FifoQ is full, so we cannot add another item.\n";
      else
      { last ++;
        queue[last] = i;
      }
    }

    int deleteFirst ()
    { int i;

      if (isEmpty())
      { cout << "FifoQ is empty, so we cannot delete first item.\n";
        return 0;
      }
      else
      { i = queue[first];
        first ++;
        return i;
      }
    }

  private:
    int queue[maxC],
        first, last;

}; // FifoQ

//*************************************************************************

// Check if value is in the interval minim--maxim (inclusive).
void checkInterval (int value, int minim, int maxim)
{
  if (value<minim || value>maxim)
    cout << "The value " << value << " is not in the interval "
           << minim << "--" << maxim << ".\n";

}  // checkInterval

//*************************************************************************

// Perform Breadth First Search starting in country i0.
void BFS (int i0)
{ int i, j;
  FifoQ queue;
  AdjLEntry *entry;

  queue.add (i0);
  done[i0] = true;
  while (!(queue.isEmpty()))
  { i = queue.deleteFirst();
    entry = neighbours[i];
    while (entry!=NULL)
    { j = entry->neighbour;
      if (!done[j])
      { queue.add (j);
        done[j] = true;
      }
      entry = entry->next;
    }
  }

} // BFS

//*************************************************************************

void cleanAdjList (int C)
{ int i;
  AdjLEntry *entry,
            *next;

  for (i=1;i<=C;i++)
  { entry = neighbours[i];
    while (entry != NULL)
    { next = entry->next;
      delete (entry);
      entry = next;
    }
    neighbours[i] = NULL;
  }

} // cleanAdjList

//*************************************************************************

int main ()
{ int T, Inst;
  int C, P,
      i, j,
      X, Y,
      components;

  for (i=1;i<=maxC;i++)
    neighbours[i] = NULL;

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  { cin >> C >> P;
    checkInterval (C, 1, maxC);
    checkInterval (P, 0, maxP);

    for (j=1;j<=P;j++)
    { cin >> X >> Y;
      checkInterval (X, 1, C-1);
      checkInterval (Y, X+1, C);
      neighbours[X] = new AdjLEntry (Y, neighbours[X]);
      neighbours[Y] = new AdjLEntry (X, neighbours[Y]);
    }

    for (i=1;i<=C;i++)
      done[i] = false;
    components = 0;

    for (i=1;i<=C;i++)
      if (!(done[i]))
      { BFS (i);
        components ++;
      }

    cleanAdjList (C);

    cout << components-1 << endl;
  }

  return 0;
}
