// Solution to problem E. European Energy Union, from CCSS 2015.
//
// Uses adjacency list representation of graph.
// Uses repeated depth first search to find connected components.
//
// Solution by Rudy van Vliet, 29 April 2015

#include <iostream>
using namespace std;
const int maxC = 2000;
const int maxP = 1000000;
bool done[maxC+1];

class AdjLEntry
{ public:
    AdjLEntry (int nwNeighbour, AdjLEntry *nwNext)
    { neighbour = nwNeighbour;
      next = nwNext;
    }

    int neighbour;
    AdjLEntry *next;
};

AdjLEntry *neighbours[maxC+1];

//*************************************************************************

// Check if value is in the interval minim--maxim (inclusive).
void checkInterval (int value, int minim, int maxim)
{
  if (value<minim || value>maxim)
    cout << "The value " << value << " is not in the interval "
           << minim << "--" << maxim << ".\n";

}  // checkInterval

//*************************************************************************

// Perform recursive Depth First Search starting in country i0.
void DFS (int i0)
{ int j;
  AdjLEntry *entry;

  entry = neighbours[i0];
  while (entry!=NULL)
  { j = entry->neighbour;
    if (!done[j])
    { done[j] = true;
      DFS (j);
    }
    entry = entry->next;
  }

} // DFS

//*************************************************************************

void cleanAdjList (int C)
{ int i;
  AdjLEntry *entry,
            *next;

  for (i=1;i<=C;i++)
  { entry = neighbours[i];
    while (entry != NULL)
    { next = entry->next;
      delete (entry);
      entry = next;
    }
    neighbours[i] = NULL;
  }

} // cleanAdjList

//*************************************************************************

int main ()
{ int T, Inst;
  int C, P,
      i, j,
      X, Y,
      components;

  for (i=1;i<=maxC;i++)
    neighbours[i] = NULL;

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  { cin >> C >> P;
    checkInterval (C, 1, maxC);
    checkInterval (P, 0, maxP);

    for (j=1;j<=P;j++)
    { cin >> X >> Y;
      checkInterval (X, 1, C-1);
      checkInterval (Y, X+1, C);
      neighbours[X] = new AdjLEntry (Y, neighbours[X]);
      neighbours[Y] = new AdjLEntry (X, neighbours[Y]);
    }

    for (i=1;i<=C;i++)
      done[i] = false;
    components = 0;

    for (i=1;i<=C;i++)
      if (!(done[i]))
      { done[i] = true;
        DFS (i);
        components ++;
      }

    cleanAdjList (C);

    cout << components-1 << endl;
  }

  return 0;
}
